@@ -9,6 +9,8 @@ final class cggm_map_operations
   static private $_sidebar_tpl;
   static private $_dirform_tpl;
   static private $_baloonform_tpl;
+  static private $_maps;
+  static private $_map_name_map;
 
   private function __construct() {}
 
@@ -44,6 +46,7 @@ final class cggm_map_operations
     $obj->set_name($row['name']);
     $obj->set_owner_id($row['owner_id']);
     $obj->set_data($row['data']);
+
     return $obj;
   }
 
@@ -82,40 +85,43 @@ final class cggm_map_operations
 
   public static function load_by_id($map_id,$deep = false)
   {
-    global $gCms;
-    $db = $gCms->GetDb();
-    $query = 'SELECT * FROM '.cms_db_prefix().'module_cggooglemaps WHERE map_id = ?';
-    $row = $db->GetRow($query,array($map_id));
-    if( !$row ) return FALSE;
+    if( !isset(self::$_maps[$map_id]) ) {
+      $db = cmsms()->GetDb();
+      $query = 'SELECT * FROM '.cms_db_prefix().'module_cggooglemaps WHERE map_id = ?';
+      $row = $db->GetRow($query,array($map_id));
+      if( !$row ) return FALSE;
 
-    $obj = self::row_to_map($row);
-    if( $obj && $deep )
-      {
-	// load points.
-	cggm_marker_operations::load_markers_for_map($obj);
-      }
-    return $obj;
+      $obj = self::row_to_map($row);
+      if( !is_array(self::$_maps) ) self::$_maps = array();
+      self::$_maps[$map_id] = $obj;
+    }
+
+    if( $deep && !self::$_maps[$map_id]->count_markers() ) cggm_marker_operations::load_markers_for_map(self::$_maps[$map_id]);
+    return self::$_maps[$map_id];
   }
 
 
   public static function load_by_name($map_name,$deep = false)
   {
-    global $gCms;
-    $db = $gCms->GetDb();
-    $query = 'SELECT * FROM '.cms_db_prefix().'module_cggooglemaps WHERE name = ?';
-    $row = $db->GetRow($query,array($map_name));
-    if( !$row ) return FALSE;
+    if( (int)$map_name > 0 ) return self::load_by_id($map_name,$deep);
 
-    $obj = self::row_to_map($row);
-    if( $obj && $deep )	cggm_marker_operations::load_markers_for_map($obj); // load points.
-    return $obj;
+    $db = cmsms()->GetDb();
+    if( !is_array(self::$_map_name_map) ) {
+      $query = 'SELECT map_id,name FROM '.cms_db_prefix().'module_cggooglemaps';
+      $tmp = $db->GetArray($query);
+      if( !is_array($tmp) || count($tmp) == 0 ) return;
+      self::$_map_name_map = cge_array::to_hash($tmp,'name');
+    }
+
+    if( !isset(self::$_map_name_map[$map_name]) ) return;
+    $id = self::$_map_name_map[$map_name]['map_id'];
+    return self::load_by_id($id,$deep);
   }
 
 
   public static function delete(cggm_map& $map)
   {
-    global $gCms;
-    $db = $gCms->GetDb();
+    $db = cmsms()->GetDb();
     $map_id = $map->get_id();
 
     $query = 'DELETE FROM '.cms_db_prefix().'module_cggooglemaps_points WHERE map_id = ?';
@@ -131,6 +137,8 @@ final class cggm_map_operations
     $this->DeleteTemplate('mapcategory_'.$map_id);
     $this->DeleteTemplate('mapdirform_'.$map_id);
     $this->DeleteTemplate('mapbaloon_'.$map_id);
+    self::$_maps = null;
+    self::$_map_name_map = null;
     return TRUE;
   }
 
@@ -139,8 +147,7 @@ final class cggm_map_operations
   {
     $query = 'INSERT '.cms_db_prefix().'module_cggooglemaps (name,owner_id,data) VALUES (?,?,?)';
 
-    global $gCms;
-    $db = $gCms->GetDb();
+    $db = cmsms()->GetDb();
     $dbr = $db->Execute($query,self::map_to_row($map));
     if( !$dbr ) die($db->sql.'<br/>'.$db->ErrorMsg());
     if( !$dbr ) return FALSE;
@@ -168,6 +175,8 @@ final class cggm_map_operations
 
     $tmp = $map->get_baloon_template(true);
     if( $tmp ) $mod->SetTemplate('mapbaloon_'.$map->get_id(),$tmp);
+    self::$_maps = null;
+    self::$_map_name_map = null;
     return TRUE;
   }
 
@@ -177,8 +186,7 @@ final class cggm_map_operations
     $query = 'UPDATE '.cms_db_prefix().'module_cggooglemaps
               SET name = ?, owner_id = ?, data = ?
               WHERE map_id = ?';
-    global $gCms;
-    $db = $gCms->GetDb();
+    $db = cmsms()->GetDb();
     $tmp = self::map_to_row($map);
     $tmp[] = $map->get_id();
     $dbr = $db->Execute($query,$tmp);
@@ -204,6 +212,8 @@ final class cggm_map_operations
     if( $tmp ) $mod->SetTemplate('mapdirform_'.$map->get_id(),$tmp);
     $tmp = $map->get_baloon_template(true);
     if( $tmp ) $mod->SetTemplate('mapbaloon_'.$map->get_id(),$tmp);
+    self::$_maps = null;
+    self::$_map_name_map = null;
     return TRUE;
   }
 
